---
name: Bug report
about: Create a report to help us improve
title: ''
labels: 'bug'
assignees: ''

---

# Describe the bug

<!-- A clear and concise description of what the bug is. -->


# To Reproduce

<!-- Steps to reproduce the behavior: -->
<!-- 1. Go to '...' -->
<!-- 2. Click on '....' -->
<!-- 3. Scroll down to '....' -->
<!-- 4. See error -->


# Expected behavior

<!-- A clear and concise description of what you expected to happen. -->


# Screenshots

<!-- If applicable, add screenshots to help explain your problem. -->


# Environment

<!-- Please complete the following information: -->
<!-- - Beamline -->
<!-- - Environment (e.g. "haven" or "haven-dev") -->
<!-- - User -->


# Additional context

<!-- Add any other context about the problem here. For example: -->
<!--  - Scan UID -->
